##  Search
Here you can configure the search and filtering options for the users.
Enable alias search to make it easier for users to find a fact sheet that is known under a commonly used alternative name or abbreviation.
**Note**
If the switch for alias search is grayed out, it indicates that the fact sheet type of your portal does not have the Alias field configured yet. To enable alias search, you configure the Alias field in the meta model configuration and activate full-text search for the field.
![Portal configuration screen showing search and filter options settings.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ed3507a4410149d94a24a782cdb67_LowRes.png)
